# Installation (Ubuntu 14.04)

## Ubuntu 14.04

Install sass

```
$ sudo apt-get install ruby
$ sudo gem install sass -v 3.4.17
```

## Fedora 26

Install sass

```
$ sudo dnf install -y ruby
$ sudo gem install sass -v 3.4.17
```

## Install dependencies

See `static/spirit/scripts/src` for instructions

## Build

```
$ npm run gulp css
```
